Changelog
=========

0.5.0
-----

* Bump canonical_json to 0.5.0 (#37)
* Bump serde_json to 1.0.91 (#34)
* Bump serde to 1.0.152 (#36)
* Bump pyo3 to 0.17.3 (#28)
* Bump regex to 1.5.6 (#6)
* Bump lock_api to 0.4.7 (#5)

0.4.0
-----

* Upgrade to canonical_json 0.4.0

0.3.0
-----

* Initial version
